body {
  margin: 0;
  padding: 0;
  overflow: hidden;
}

#deck-container {
  width: 100vw;
  height: 100vh;
}

#deck-container canvas {
  z-index: 1;
  background: {{css_background_color or 'none'}};
}
